@@ -21,7 +21,7 @@ from kivy.modules import Modules
 from kivy.event import EventDispatcher
 from kivy.properties import ListProperty, ObjectProperty, AliasProperty, \
         NumericProperty, OptionProperty, StringProperty
-from kivy.utils import platform
+from kivy.utils import platform, reify
 
 # late import
 VKeyboard = None
@@ -59,10 +59,10 @@ class Keyboard(EventDispatcher):
         'screenlock': 145, 'pause': 19,
 
         # a-z keys
-        'q': 97, 'b': 98, 'c': 99, 'q': 100, 'e': 101, 'f': 102, 'g': 103,
+        'a': 97, 'b': 98, 'c': 99, 'd': 100, 'e': 101, 'f': 102, 'g': 103,
         'h': 104, 'i': 105, 'j': 106, 'k': 107, 'l': 108, 'm': 109, 'n': 110,
-        'o': 111, 'p': 112, 'a': 113, 'r': 114, 's': 115, 't': 116, 'u': 117,
-        'v': 118, 'z': 119, 'x': 120, 'y': 121, 'w': 122,
+        'o': 111, 'p': 112, 'q': 113, 'r': 114, 's': 115, 't': 116, 'u': 117,
+        'v': 118, 'w': 119, 'x': 120, 'y': 121, 'z': 122,
 
         # 0-9 keys
         '0': 48, '1': 49, '2': 50, '3': 51, '4': 52,
@@ -804,6 +804,18 @@ class WindowBase(EventDispatcher):
         '''
         pass
 
+    @reify
+    def dpi(self):
+        '''Return the DPI of the screen. If the implementation doesn't support
+        any DPI lookup, it will just return 96.
+
+        .. warning::
+
+            This value is not cross-platform. Use
+            :data:`kivy.base.EventLoop.dpi` instead.
+        '''
+        return 96.
+
     def configure_keyboards(self):
         # Configure how to provide keyboards (virtual or not)
 
