@@ -5,6 +5,7 @@ class FileChooserTestCase(GraphicUnitTest):
 
     def test_filechooserlistview(self):
         from kivy.uix.filechooser import FileChooserListView
+        from os.path import expanduser
         r = self.render
-        wid = FileChooserListView(path='/home/tito/Images')
+        wid = FileChooserListView(path=expanduser('~'))
         r(wid, 2)
