@@ -12,59 +12,57 @@ TabbedPanel
     This widget is still experimental, and its API is subject to change in a
     future version.
 
-The `TabbedPanel` widget provides you a way to manage different widgets in
-each tab.
+The `TabbedPanel` widget manages different widgets in tabs, with a header area
+for the actual tab buttons and a content area for showing current tab content.
 
-The :class:`TabbedPanel` auto provides one (default tab) tab and also
-automatically deletes it when `default_tab` is changed, thus maintaining
-at least one default tab at any given time.
+The :class:`TabbedPanel` provides one default tab.
 
 Simple example
 --------------
 
-.. include :: ../../examples/widgets/tabbedpanel.py
+.. include:: ../../examples/widgets/tabbedpanel.py
     :literal:
 
-Customize the Panel
------------------------
+Customize the Tabbed Panel
+--------------------------
 
-You can choose the direction the tabbs are displayed::
+You can choose the direction the tabs are displayed::
 
     tab_pos = 'top_mid'
 
-The widgets added to Panel are orderd by default horizintally like in a
-Boxlayout. You can change that by::
-
-    orientation = 'vertical'
-
-Add Tabs/Headings::
+An individual tab is called a TabbedPanelHeader. It is a special button
+containing a content property. You add the TabbedPanelHeader first, and set its
+content separately::
 
     tp = TabbedPanel()
     th = TabbedPanelHeader(text='Tab2')
     tp.add_widget(th)
 
-Change the text of default Tab::
-
-    tp.default_tab_text = 'tab head'
-
-Add Items to the Panel/content area::
-
-    tp.add_widget(your_widget_instance)
-
-Note: There is only one content area shared by all the tabs. Each tab heading
-is itself responsible for clearing that content area and adding the widgets it
-needs to display to the content area.
-
-Set panel contents::
+An individual tab, represented by a TabbedPanelHeader, needs its content set.
+This content can be any of the widget choices. It could be a layout with a deep
+hierarchy of widget, or it could be an indivual widget, such as a label or
+button::
 
     th.content = your_content_instance
 
-Since the default tab exists by default, a `on_default_tab` event is provided.
-To facilitate custom jobs you might want to do on that event::
+Note: There is one "shared" main content area, active at a given time, for all
+the tabs. Your app is responsible for adding the content of individual tabs,
+and for managing it, but not for doing the content switching. The tabbed panel
+handles switching of the main content object, per user action.
+
+There is always a default tab added when the tabbed panel is instantiated.
+Tabs that you add individually as above, are added in addition to the default
+tab. Thus, depending on your needs and design, you will want to customize the
+default tab, including its text::
+
+    tp.default_tab_text = 'Something Specific To Your Use'
+
+The default tab machinery requires special consideration and management.
+Accordingly, an `on_default_tab` event is provided for associating a callback::
 
     tp.bind(on_default_tab = my_default_tab_callback)
 
-Remove Items::
+Tabs and content can be removed in several ways::
 
     tp.remove_widget(Widget/TabbedPanelHeader)
     or
@@ -73,29 +71,28 @@ Remove Items::
     tp.clear_tabs() # to remove the TabbedPanelHeaders
 
 .. warning::
-    Access children list, This is important! use content.children to
-    access the children list::
+    To access the children of the tabbed panel, use content.children::
 
         tp.content.children
 
-To Access the list of Tabs::
+To access the list of tabs::
 
     tp.tab_list
 
-Change Appearance of the TabbedPanel::
+To change the appearance of the main tabbed panel content::
 
     background_color = (1, 0, 0, .5) #50% translucent red
     border = [0, 0, 0, 0]
     background_image = 'path/to/background/image'
-    tab_image = 'path/to/tab/image'
 
-Change the appearance of the Tab Head::
+To change the background of a individual tab, use these two properties::
 
-    tab_heading_instance.background_normal = 'path/to/tab_head/img'
-    tab_heading_instance.background_down = 'path/to/tab_head/img_pressed'
+    tab_header_instance.background_normal = 'path/to/tab_head/img'
+    tab_header_instance.background_down = 'path/to/tab_head/img_pressed'
 
-Change The Background of the tab strip override the canvas of TabbedPanelStrip
-in your kv language::
+A TabbedPanelStrip contains the individual tab headers. To change the
+appearance of this tab strip, override the canvas of TabbedPanelStrip.
+For example, in the kv language::
 
     <TabbedPanelStrip>
         canvas:
@@ -105,13 +102,13 @@ in your kv language::
                 size: self.size
                 pos: self.pos
 
-by default The tab strip takes it's background image, color from the
-TabbedPanel's background_image and background_color respectively.
+By default the tabbed panel strip takes its background image and color from the
+tabbed panel's background_image and background_color.
 
 '''
 
 __all__ = ('TabbedPanel', 'TabbedPanelContent', 'TabbedPanelHeader',
-    'TabbedPanelStrip')
+    'TabbedPanelStrip', 'TabbedPanelException')
 
 from functools import partial
 from kivy.clock import Clock
@@ -121,21 +118,30 @@ from kivy.uix.widget import Widget
 from kivy.uix.scatter import Scatter
 from kivy.uix.scrollview import ScrollView
 from kivy.uix.gridlayout import GridLayout
+from kivy.uix.floatlayout import FloatLayout
 from kivy.logger import Logger
 from kivy.properties import ObjectProperty, StringProperty, OptionProperty, \
         ListProperty, NumericProperty, AliasProperty
 
 
-class TabbedPanelHeader(ToggleButton):
-    '''A button intented to be used as a Heading/Tab for TabbedPanel widget.
+class TabbedPanelException(Exception):
+    '''The TabbedPanelException class.
+    '''
+    pass
 
-    You can use this TabbedPanelHeader widget to add a new tab to TabbedPanel
+
+class TabbedPanelHeader(ToggleButton):
+    '''A Base for implementing a Tabbed Panel Head. A button intended to be
+    used as a Heading/Tab for TabbedPanel widget.
+
+    You can use this TabbedPanelHeader widget to add a new tab to TabbedPanel.
     '''
 
     content = ObjectProperty(None)
-    '''content to be loaded when this tab heading is selected
+    '''Content to be loaded when this tab header is selected.
 
-    :data:`content` is a :class:`~kivy.properties.ObjectProperty`
+    :data:`content` is a :class:`~kivy.properties.ObjectProperty` default
+    to None .
     '''
 
     # only allow selecting the tab if not already selected
@@ -149,8 +155,6 @@ class TabbedPanelHeader(ToggleButton):
             super(TabbedPanelHeader, self).on_touch_down(touch)
 
     def on_release(self, *l):
-        if not self.content:
-            return
         parent = self.parent
         while parent is not None and not isinstance(parent, TabbedPanel):
             parent = parent.parent
@@ -160,18 +164,24 @@ class TabbedPanelHeader(ToggleButton):
 
 
 class TabbedPanelStrip(GridLayout):
-    '''A strip intented to be used as background for Heading/Tab.
-    see module documentation for details.
+    '''A strip intended to be used as background for Heading/Tab.
     '''
     tabbed_panel = ObjectProperty(None)
+    '''link to the panel that tab strip is a part of.
+
+    :data:`tabbed_panel` is a :class:`~kivy.properties.ObjectProperty` default
+    to None .
+    '''
 
 
-class TabbedPanelContent(GridLayout):
+class TabbedPanelContent(FloatLayout):
+    '''The TabbedPanelContent class.
+    '''
     pass
 
 
 class TabbedPanel(GridLayout):
-    '''Panel class, see module documentation for more information.
+    '''The TabbedPanel class. See module documentation for more information.
     '''
 
     background_color = ListProperty([1, 1, 1, 1])
@@ -184,53 +194,77 @@ class TabbedPanel(GridLayout):
     border = ListProperty([16, 16, 16, 16])
     '''Border used for :class:`~kivy.graphics.vertex_instructions.BorderImage`
     graphics instruction, used itself for :data:`background_image`.
-    Can be used when using custom background.
+    Can be changed for a custom background.
 
-    It must be a list of 4 value: (top, right, bottom, left). Read the
-    BorderImage instruction for more information about how to play with it.
+    It must be a list of four values: (top, right, bottom, left). Read the
+    BorderImage instructions for more information.
 
     :data:`border` is a :class:`~kivy.properties.ListProperty`,
     default to (16, 16, 16, 16)
     '''
 
     background_image = StringProperty('atlas://data/images/defaulttheme/tab')
-    '''Background image of the Tab content
+    '''Background image of the main shared content object.
 
     :data:`background_image` is a :class:`~kivy.properties.StringProperty`,
     default to 'atlas://data/images/defaulttheme/tab'.
     '''
 
+    def get_current_tab(self):
+        return self._current_tab
+
+    current_tab = AliasProperty(get_current_tab, None)
+    '''Links to the currently select or active tab.
+
+    .. versionadded:: 1.4.0
+
+    :data:`current_tab` is a :class:`~kivy.AliasProperty`, read-only.
+    '''
+
     tab_pos = OptionProperty('top_left',
             options=('left_top', 'left_mid', 'left_bottom', 'top_left',
                 'top_mid', 'top_right', 'right_top', 'right_mid',
                 'right_bottom', 'bottom_left', 'bottom_mid', 'bottom_right'))
     '''Specifies the position of the tabs relative to the content.
-    Can be one of: left_top, left_mid, left_bottom top_left, top_mid, top_right
-    right_top, right_mid, right_bottom bottom_left, bottom_mid, bottom_right.
+    Can be one of: `left_top`, `left_mid`, `left_bottom`, `top_left`,
+    `top_mid`, `top_right`, `right_top`, `right_mid`, `right_bottom`,
+    `bottom_left`, `bottom_mid`, `bottom_right`.
 
     :data:`tab_pos` is a :class:`~kivy.properties.OptionProperty`,
     default to 'bottom_mid'.
     '''
 
     tab_height = NumericProperty(40)
-    '''Specifies the height of the Tab Heading
+    '''Specifies the height of the tab header.
 
     :data:`tab_height` is a :class:`~kivy.properties.NumericProperty`,
-    default to '20'.
+    default to 40.
     '''
 
     tab_width = NumericProperty(100, allownone=True)
-    '''Specifies the width of the Tab Heading
+    '''Specifies the width of the tab header.
 
     :data:`tab_width` is a :class:`~kivy.properties.NumericProperty`,
-    default to '100'.
+    default to 100.
     '''
 
     default_tab_text = StringProperty('Default tab')
-    '''Specifies the Text displayed on the default tab Heading
+    '''Specifies the text displayed on the default tab header.
 
     :data:`default_tab_text` is a :class:`~kivy.properties.StringProperty`,
-    default to 'default tab'.
+    defaults to 'default tab'.
+    '''
+
+    default_tab_cls = ObjectProperty(TabbedPanelHeader)
+    '''Specifies the class to use for the styling of the default tab.
+
+    .. versionadded:: 1.4.0
+
+    .. warning::
+        `default_tab_cls` should be subclassed from `TabbedPanelHeader`
+
+    :data:`default_tab_cls` is a :class:`~kivy.properties.ObjectProperty`,
+    default to `TabbedPanelHeader`.
     '''
 
     def get_tab_list(self):
@@ -239,14 +273,14 @@ class TabbedPanel(GridLayout):
         return 1.
 
     tab_list = AliasProperty(get_tab_list, None)
-    '''List of all the tab headers
+    '''List of all the tab headers.
 
     :data:`tab_list` is a :class:`~kivy.properties.AliasProperty`, and is
     read-only.
     '''
 
     content = ObjectProperty(None)
-    '''This is the object where the main content of the current tab is held
+    '''This is the object holding the content of the current tab.
 
     :data:`content` is a :class:`~kivy.properties.ObjectProperty`,
     default to 'None'.
@@ -256,21 +290,24 @@ class TabbedPanel(GridLayout):
         return self._default_tab
 
     def set_def_tab(self, new_tab):
+        if not issubclass(new_tab.__class__, TabbedPanelHeader):
+            raise TabbedPanelException('`default_tab_class` should be\
+                subclassed from `TabbedPanelHeader`')
         if  self._default_tab == new_tab:
             return
         oltab = self._default_tab
         self._default_tab = new_tab
-        if self._original_tab == oltab:
+        if hasattr(self, '_original_tab') and self._original_tab == oltab:
             self.remove_widget(oltab)
-            self._origina_tab = None
+            self._original_tab = None
         self.switch_to(new_tab)
         new_tab.state = 'down'
 
     default_tab = AliasProperty(get_def_tab, set_def_tab)
-    '''Holds the default_tab
+    '''Holds the default tab.
 
-    .. Note:: for convenience the auto provided default tab is also deleted
-    once you change default_tab to something else.
+    .. Note:: For convenience, the automatically provided default tab is deleted
+              when you change default_tab to something else.
 
     :data:`default_tab` is a :class:`~kivy.properties.AliasProperty`
     '''
@@ -283,71 +320,91 @@ class TabbedPanel(GridLayout):
 
     default_tab_content = AliasProperty(get_def_tab_content,
         set_def_tab_content)
-    '''Holds the default_tab_content
+    '''Holds the default tab content.
 
     :data:`default_tab_content` is a :class:`~kivy.properties.AliasProperty`
     '''
 
-    orientation = OptionProperty('horizontal',
-            options=('horizontal', 'vertical'))
-    '''This specifies the manner in which the children inside panel content
-    are arranged. can be one of 'vertical', 'horizontal'
-
-    :data:`orientation` is a :class:`~kivy.properties.OptionProperty`,
-    default to 'horizontal'.
-    '''
-
     def __init__(self, **kwargs):
-        self._tab_layout = GridLayout(rows = 1)
+        self._tab_layout = GridLayout(rows=1)
         self._bk_img = Image(
             source=self.background_image, allow_stretch=True,
             keep_ratio=False, color=self.background_color)
         self._tab_strip = _tabs = TabbedPanelStrip(tabbed_panel=self,
-            rows=1, cols=99, size_hint=(None, None),\
+            rows=1, cols=99, size_hint=(None, None),
             height=self.tab_height, width=self.tab_width)
-        self._original_tab = self._default_tab = default_tab = \
-            TabbedPanelHeader(text=self.default_tab_text,
-                height=self.tab_height, state='down',
-                width=self.tab_width)
-        _tabs.add_widget(default_tab)
-        default_tab.group = '__tab%r__' %_tabs.uid
+
         self._partial_update_scrollview = None
-
         self.content = content = TabbedPanelContent()
-        super(TabbedPanel, self).__init__(**kwargs)
-        self.add_widget(content)
-        self.on_tab_pos()
-        #make default tab the active tab
-        self.switch_to(self._default_tab)
 
-    def on_default_tab_text(self, *l):
+        self._current_tab = default_tab = self._original_tab \
+            = self._default_tab = TabbedPanelHeader()
+        super(TabbedPanel, self).__init__(**kwargs)
+
+        content = self._default_tab.content
+        cls = self.default_tab_cls
+        if not issubclass(cls, TabbedPanelHeader):
+            raise TabbedPanelException('`default_tab_class` should be\
+                subclassed from `TabbedPanelHeader`')
+
+        if cls != type(default_tab):
+            self._default_tab = cls()
+        default_tab = self.default_tab
+        default_tab.text = self.default_tab_text
+        default_tab.height = self.tab_height
+        default_tab.group = '__tab%r__' % _tabs.uid
+        default_tab.state = 'down'
+        default_tab.width = self.tab_width if self.tab_width else 100
+        default_tab.content = content
+
+        tl = self.tab_list
+        if default_tab not in tl:
+            _tabs.add_widget(default_tab, len(tl))
+
+        if default_tab.content:
+            self.clear_widgets()
+            self.add_widget(self.default_tab.content)
+        else:
+            Clock.schedule_once(self._load_default_tab_content)
+        self._current_tab = default_tab
+        self.on_tab_pos()
+
+    def _load_default_tab_content(self, dt):
+        self.switch_to(self.default_tab)
+
+    def on_default_tab_text(self, *args):
         self._default_tab.text = self.default_tab_text
 
     def switch_to(self, header):
-        '''Switch to a specific panel header
+        '''Switch to a specific panel header.
         '''
-        if header.content is None:
-            return
+        header_content = header.content
+        self._current_tab = header
         self.clear_widgets()
+        if header_content is None:
+            return
         # if content has a previous parent remove it from that parent
-        parent = header.content.parent
-        if header.content.parent:
-            parent.remove_widget(header.content)
-        self.add_widget(header.content)
+        parent = header_content.parent
+        if parent:
+            parent.remove_widget(header_content)
+        self.add_widget(header_content)
 
     def add_widget(self, widget, index=0):
         content = self.content
         if content is None:
             return
+        parent = widget.parent
+        if widget.parent:
+            parent.remove_widget(widget)
         if widget == content or widget == self._tab_layout:
             super(TabbedPanel, self).add_widget(widget, index)
         elif isinstance(widget, TabbedPanelHeader):
             self_tabs = self._tab_strip
-            self_tab_width = self.tab_width
             self_tabs.add_widget(widget)
             widget.group = '__tab%r__' % self_tabs.uid
             self.on_tab_width()
         else:
+            widget.pos_hint = {'x': 0, 'top': 1}
             content.add_widget(widget, index)
 
     def remove_widget(self, widget):
@@ -366,9 +423,9 @@ class TabbedPanel(GridLayout):
                 self.reposition_tabs()
             else:
                 Logger.info('TabbedPanel: default tab! can\'t be removed.\n' +
-                    'change `default_tab` to a different tab to remove this.')
+                    'Change `default_tab` to a different tab.')
         else:
-            content.remove_widget(l[0])
+            content.remove_widget(widget)
 
     def clear_widgets(self, **kwargs):
         content = self.content
@@ -389,7 +446,7 @@ class TabbedPanel(GridLayout):
 
     def reposition_tabs(self, *l):
         Clock.unschedule(self.on_tab_pos)
-        Clock.schedule_once(self.on_tab_pos)
+        Clock.schedule_once(self.on_tab_pos, 0)
 
     def on_background_image(self, *l):
         self._bk_img.source = self.background_image
@@ -399,17 +456,6 @@ class TabbedPanel(GridLayout):
             return
         self._bk_img.color = self.background_color
 
-    def on_orientation(self, *l):
-        content = self.content
-        if not content:
-            return
-        if self.orientation[0] == 'v':
-            content.cols = 1
-            content.rows = 99
-        else:
-            content.cols = 99
-            content.rows = 1
-
     def on_tab_width(self, *l):
         Clock.unschedule(self.update_tab_width)
         Clock.schedule_once(self.update_tab_width, 0)
@@ -427,7 +473,7 @@ class TabbedPanel(GridLayout):
                     # size_hint_x: x/.xyz
                     tab.size_hint_x = 1
                     #drop to default tab_width
-                    tsw = 100 * len(self._tab_strip.children)
+                    tsw += 100
                 else:
                     # size_hint_x: None
                     tsw += tab.width
@@ -448,6 +494,9 @@ class TabbedPanel(GridLayout):
         tab_layout.clear_widgets()
         scrl_v = ScrollView(size_hint=(None, 1))
         tabs = self._tab_strip
+        parent = tabs.parent
+        if parent:
+            parent.remove_widget(tabs)
         scrl_v.add_widget(tabs)
         scrl_v.pos = (0, 0)
         self_update_scrollview = self._update_scrollview
@@ -516,13 +565,13 @@ class TabbedPanel(GridLayout):
 
             # rotate the scatter for vertical positions
             rotation = 90 if tab_pos[0] == 'l' else -90
-            sctr = Scatter(do_translation = False,
-                               rotation = rotation,
-                               do_rotation = False,
-                               do_scale = False,
-                               size_hint = (None, None),
-                               auto_bring_to_front = False,
-                               size=scrl_v.size)
+            sctr = Scatter(do_translation=False,
+                    rotation=rotation,
+                    do_rotation=False,
+                    do_scale=False,
+                    size_hint=(None, None),
+                    auto_bring_to_front=False,
+                    size=scrl_v.size)
             sctr.add_widget(scrl_v)
 
             lentab_pos = len(tab_pos)
@@ -535,17 +584,16 @@ class TabbedPanel(GridLayout):
             # scatter. Without clock.schedule_once the positions would look
             # fine but touch won't translate to the correct position
 
-            if tab_pos[lentab_pos-4:] == '_top':
+            if tab_pos[lentab_pos - 4:] == '_top':
                 #on positions 'left_top' and 'right_top'
-                sctr.bind(pos = Clock.schedule_once(
-                    partial(self._update_top, sctr, 'top', None), -1))
+                sctr.bind(pos=partial(self._update_top, sctr, 'top', None))
                 tab_list = (sctr, )
-            elif tab_pos[lentab_pos-4:] == '_mid':
+            elif tab_pos[lentab_pos - 4:] == '_mid':
                 #calculate top of scatter
-                sctr.bind(pos = Clock.schedule_once(
-                    partial(self._update_top, sctr, 'mid', scrl_v.width), -1))
+                sctr.bind(pos=partial(self._update_top, sctr, 'mid',
+                    scrl_v.width))
                 tab_list = (Widget(), sctr, Widget())
-            elif tab_pos[lentab_pos-7:] == '_bottom':
+            elif tab_pos[lentab_pos - 7:] == '_bottom':
                 tab_list = (Widget(), Widget(), sctr)
 
             if pos_letter == 'l':
@@ -563,11 +611,16 @@ class TabbedPanel(GridLayout):
         for widg in widget_list:
             add(widg)
 
-    def _update_top(self, sctr, top, scrl_v_width, dt):
+    def _update_top(self, *args):
+        sctr, top, scrl_v_width, x, y = args
+        Clock.unschedule(partial(self._updt_top, sctr, top, scrl_v_width))
+        Clock.schedule_once(partial(self._updt_top, sctr, top, scrl_v_width), 0)
+
+    def _updt_top(self, sctr, top, scrl_v_width, *args):
         if top[0] == 't':
             sctr.top = self.top
         else:
-            sctr.top = self.top - (self.height - scrl_v_width)/2
+            sctr.top = self.top - (self.height - scrl_v_width) / 2
 
     def _update_scrollview(self, scrl_v, *l):
         self_tab_pos = self.tab_pos
