@@ -199,7 +199,7 @@ class TextInput(Widget):
         self._selection_finished = True
         self._selection_touch = None
         self.selection_text = ''
-        self.__selection_from = None
+        self._selection_from = None
         self._selection_to = None
         self._bubble = None
         self._lines_flags = []
@@ -419,7 +419,7 @@ class TextInput(Widget):
                 self._selection = True
                 self.delete_selection(True)
             elif undo_type == 'bkspc':
-                substring = x_item['undo_command'][2:]
+                substring = x_item['undo_command'][2:][0]
                 self.insert_text(substring, True)
             else:
                 # delsel
@@ -1074,9 +1074,15 @@ class TextInput(Widget):
 
     def _get_line_options(self):
         # Get or create line options, to be used for Label creation
+
+        # XXX font_size core label compatibility
+        factor = 1.
+        if TextInput.font_size.get_format(self) == 'px':
+            factor = 1.333
+
         if self._line_options is None:
             self._line_options = kw = {
-                'font_size': self.font_size,
+                'font_size': self.font_size * factor,
                 'font_name': self.font_name,
                 'anchor_x': 'left',
                 'anchor_y': 'top',
@@ -1466,6 +1472,40 @@ class TextInput(Widget):
     to [0.1843, 0.6549, 0.8313, .5]
     '''
 
+    border = ListProperty([16, 16, 16, 16])
+    '''Border used for :class:`~kivy.graphics.vertex_instructions.BorderImage`
+    graphics instruction. Used with :data:`background_normal` and
+    :data:`background_active`. Can be used for a custom background.
+
+    .. versionadded:: 1.4.1
+
+    It must be a list of four values: (top, right, bottom, left). Read the
+    BorderImage instruction for more information about how to use it.
+
+    :data:`border` is a :class:`~kivy.properties.ListProperty`, default to (16,
+    16, 16, 16)
+    '''
+
+    background_normal = StringProperty(
+        'atlas://data/images/defaulttheme/textinput')
+    '''Background image of the TextInput when it's not in focus'.
+
+    .. versionadded:: 1.4.1
+
+    :data:`background_normal` is a :class:`~kivy.properties.StringProperty`,
+    default to 'atlas://data/images/defaulttheme/textinput'
+    '''
+
+    background_active = StringProperty(
+        'atlas://data/images/defaulttheme/textinput_active')
+    '''Background image of the TextInput when it's in focus'.
+
+    .. versionadded:: 1.4.1
+
+    :data:`background_active` is a :class:`~kivy.properties.StringProperty`,
+    default to 'atlas://data/images/defaulttheme/textinput_active'
+    '''
+
     background_color = ListProperty([1, 1, 1, 1])
     '''Current color of the background, in (r, g, b, a) format.
 
