@@ -3,15 +3,15 @@ Video
 =====
 
 The :class:`Video` widget is used to display video files and streams. Depending
-on your Video core provider, platform and plugins you will be able to play
-different formats. For example, pygame video provider only supports MPEG1 on
+on your Video core provider, platform, and plugins, you will be able to play
+different formats. For example, the pygame video provider only supports MPEG1 on
 Linux and OSX. GStreamer is more versatile, and can read many video containers
 and codecs such as MKV, OGV, AVI, MOV, FLV (if the correct gstreamer plugins
 are installed). Our :class:`~kivy.core.video.VideoBase` implementation is used
 under the hood.
 
-The video loading is asynchronous - many properties are not available until
-the video is loaded (when the texture is created). ::
+Video loading is asynchronous - many properties are not available until
+the video is loaded (when the texture is created)::
 
     def on_position_change(instance, value):
         print 'The position in the video is', value
@@ -29,16 +29,36 @@ from kivy.clock import Clock
 from kivy.uix.image import Image
 from kivy.core.video import Video as CoreVideo
 from kivy.resources import resource_find
-from kivy.properties import BooleanProperty, NumericProperty, ObjectProperty
+from kivy.properties import (BooleanProperty, NumericProperty, ObjectProperty,
+        OptionProperty)
 
 
 class Video(Image):
     '''Video class. See module documentation for more information.
     '''
 
+    state = OptionProperty('stop', options=('play', 'pause', 'stop'))
+    '''String, indicates whether to play, pause, or stop the video::
+
+        # start playing the video at creation
+        video = Video(source='movie.mkv', state='play')
+
+        # create the video, and start later
+        video = Video(source='movie.mkv')
+        # and later
+        video.state = 'play'
+
+    :data:`state` is a :class:`~kivy.properties.OptionProperty`, default to
+    'play'.
+    '''
+
     play = BooleanProperty(False)
-    '''Boolean, indicates if the video is playing.
-    You can start/stop the video by setting this property. ::
+    '''
+    .. deprecated:: 1.4.0
+        Use :data:`state` instead.
+
+    Boolean, indicates if the video is playing.
+    You can start/stop the video by setting this property::
 
         # start playing the video at creation
         video = Video(source='movie.mkv', play=True)
@@ -50,6 +70,9 @@ class Video(Image):
 
     :data:`play` is a :class:`~kivy.properties.BooleanProperty`, default to
     False.
+
+    .. deprecated:: 1.4.0
+        Use :data:`state` instead.
     '''
 
     eos = BooleanProperty(False)
@@ -60,15 +83,15 @@ class Video(Image):
     '''
 
     position = NumericProperty(-1)
-    '''Position of the video between 0 and :data:`duration`. The position is
-    default to -1, and set to real position when the video is loaded.
+    '''Position of the video between 0 and :data:`duration`. The position
+    defaults to -1, and is set to a real position when the video is loaded.
 
     :data:`position` is a :class:`~kivy.properties.NumericProperty`, default to
     -1.
     '''
 
     duration = NumericProperty(-1)
-    '''Duration of the video. The duration is default to -1, and set to real
+    '''Duration of the video. The duration defaults to -1, and is set to a real
     duration when the video is loaded.
 
     :data:`duration` is a :class:`~kivy.properties.NumericProperty`, default to
@@ -76,7 +99,7 @@ class Video(Image):
     '''
 
     volume = NumericProperty(1.)
-    '''Volume of the video, in the range 0-1. 1 mean full volume, 0 mean mute.
+    '''Volume of the video, in the range 0-1. 1 means full volume, 0 means mute.
 
     :data:`volume` is a :class:`~kivy.properties.NumericProperty`, default to
     1.
@@ -92,12 +115,11 @@ class Video(Image):
 
     def __init__(self, **kwargs):
         self._video = None
-        super(Video, self).__init__(**kwargs)
+        super(Image, self).__init__(**kwargs)
+        self.bind(source=self._trigger_video_load)
 
-    def texture_update(self, *largs):
-        '''This method is a no-op in Video widget.
-        '''
-        pass
+        if self.source:
+            self._trigger_video_load()
 
     def seek(self, percent):
         '''Change the position to a percentage of duration. Percentage must be a
@@ -105,7 +127,7 @@ class Video(Image):
 
         .. warning::
 
-            Calling seek() before video is loaded have no impact.
+            Calling seek() before video is loaded has no impact.
 
         .. versionadded:: 1.2.0
         '''
@@ -113,9 +135,6 @@ class Video(Image):
             raise Exception('Video not loaded.')
         self._video.seek(percent)
 
-    def on_source(self, instance, value):
-        self._trigger_video_load()
-
     def _trigger_video_load(self, *largs):
         Clock.unschedule(self._do_video_load)
         Clock.schedule_once(self._do_video_load, -1)
@@ -137,23 +156,31 @@ class Video(Image):
             self._video.bind(on_load=self._on_video_frame,
                              on_frame=self._on_video_frame,
                              on_eos=self._on_eos)
-            if self.play:
+            if self.state == 'play' or self.play:
                 self._video.play()
             self.duration = 1.
             self.position = 0.
 
     def on_play(self, instance, value):
+        value = 'play' if value else 'stop'
+        return self.on_state(instance, value)
+
+    def on_state(self, instance, value):
         if not self._video:
             return
-        if value:
+        if value == 'play':
             if self.eos:
                 self._video.stop()
                 self._video.position = 0.
                 self._video.eos = False
             self.eos = False
             self._video.play()
+        elif value == 'pause':
+            self._video.pause()
         else:
             self._video.stop()
+            self._video.position = 0
+            self._video.eos = False
 
     def _on_video_frame(self, *largs):
         self.duration = self._video.duration
@@ -162,7 +189,7 @@ class Video(Image):
         self.canvas.ask_update()
 
     def _on_eos(self, *largs):
-        self.play = False
+        self.state = 'stop'
         self.eos = True
 
     def on_volume(self, instance, value):
